/**
 * Implements a "reverse instant runoff voting" election. Reads data from StdIn.
 * 
 * Input format: 
 *  - the number V of voters on a line by itself
 *  - then on each of the V following lines, the preferences of that voter,
 *    from favorite to least favorite, separated by spaces
 * RIRV assumes, but does not check, that each line lists the same names.
 * 
 * usage:
 *        java-introcs RIRV < input-file.txt
 * debug mode usage (prints extra output):
 *        java-introcs RIRV -d < input-file.txt
 * (or: "run RIRV" or "run RIRV -d" in DrJava + type stdin)
 * 
 * E.g.

> more sample.txt
3
Claude David Ada Bjarne
Bjarne Ada Claude David
Ada David Claude Bjarne

> java-introcs RIRV < sample.txt
Eliminating Bjarne 
The winner is Ada 

*/
public class RIRV {
    public static void main(String[] args) {
        boolean debugMode = args.length>0 && args[0].equals("-d");
        
        int V = StdIn.readInt(); StdIn.readLine(); // go to line w/first ballot
        
        Ballot[] a = new Ballot[V];
        for (int i=0; i<V; i++) {
            // read a line, convert to array, convert to ballot
            a[i] = new Ballot(StdIn.readLine().split(" "));
        }

        if (debugMode) {
            StdOut.println("Initial ballots:");
            for (Ballot b : a) StdOut.println(b);
            StdOut.println();
        }

        while (Election.winner(a) == null) {
            String elim = Election.loser(a);
            StdOut.println("Eliminating " + elim);
            for (Ballot b : a)
                b.cut(elim);

            if (debugMode) {
                StdOut.println();
                StdOut.println("New ballots:");
                for (Ballot b : a) StdOut.println(b);
                StdOut.println();
            }
        }
        
        StdOut.println("The winner is " + Election.winner(a));
    }
}